/*
 * Copyright (c) 2016, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  WSO2 Inc. licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except
 *  in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.wso2.carbon.identity.captcha.util;

/**
 * Captcha Constants.
 */
public class CaptchaConstants {

    private static ThreadLocal enableSecurityMechanism = new ThreadLocal();

    public static final String CARBON_HOME = "carbon.home";

    public static final String ERROR_PAGE = "/authenticationendpoint/retry.do";
    public static final String ON_FAILED_LOGIN_REDIRECT_URL = "/authenticationendpoint/login.do";

    public static final String CAPTCHA_CONFIG_FILE_NAME = "captcha-config.properties";

    public static final String RE_CAPTCHA_ENABLED = "recaptcha.enabled";

    public static final String RE_CAPTCHA_TYPE = "recaptcha.type";

    public static final String FORCEFULLY_ENABLED_RECAPTCHA_FOR_ALL_TENANTS = "recaptcha" +
            ".forcefullyEnabledForAllTenants";

    public static final String RE_CAPTCHA_API_URL = "recaptcha.api.url";

    public static final String RE_CAPTCHA_VERIFY_URL = "recaptcha.verify.url";

    public static final String RE_CAPTCHA_SITE_KEY = "recaptcha.site.key";

    public static final String RE_CAPTCHA_PROJECT_ID = "recaptcha.project.id";

    public static final String RE_CAPTCHA_SECRET_KEY = "recaptcha.secret.key";

    public static final String RE_CAPTCHA_API_KEY = "recaptcha.api.key";

    public static final String RE_CAPTCHA_REQUEST_WRAP_URLS = "recaptcha.request.wrap.urls";

    public static final String FAIL_LOGIN_ATTEMPT_VALIDATOR_ENABLED = "failLoginAttemptValidator.enable";

    public static final String RE_CAPTCHA_FAILED_REDIRECT_URLS = "recaptcha.failed.redirect.urls";

    public static final String RE_CAPTCHA_SCORE_THRESHOLD = "recaptcha.threshold";

    public static final String BASIC_AUTHENTICATOR = "BasicAuthenticator";

    public static final String BASIC_AUTH_MECHANISM = "basic";

    public static final String CAPTCHA_SCORE = "score";

    public static final String CAPTCHA_SUCCESS = "success";
    public static final String ENABLE_GENERIC_CAPTCHA_VALIDATION = "enable_captcha_validation";
    public static final String RE_CAPTCHA = "reCaptcha";
    public static final String AUTH_FAILURE = "authFailure";
    public static final String AUTH_FAILURE_MSG = "authFailureMsg";
    public static final String RECAPTCHA_FAIL_MSG_KEY = "recaptcha.fail.message";
    public static final String TRUE = "true";
    public static final String CAPTCHA_VALID = "valid";
    public static final String CAPTCHA_TOKEN_PROPERTIES = "tokenProperties";
    public static final String CAPTCHA_RISK_ANALYSIS = "riskAnalysis";
    // Captcha Types.
    public static final String RE_CAPTCHA_TYPE_ENTERPRISE = "recaptcha-enterprise";

    // Default value for threshold for score in reCAPTCHA v3.
    public static final double CAPTCHA_V3_DEFAULT_THRESHOLD = 0.5;

    public static final String SSO_LOGIN_RECAPTCHA_CONNECTOR_NAME = "sso.login.recaptcha";

    /**
     * Captcha Connector configuration constants from the identity.xml.
     */
    public static final class ConnectorConfig {

        public static final String SSO_LOGIN_RECAPTCHA_ENABLED = "SSOLogin.Recaptcha.Enabled";
        public static final String SSO_LOGIN_RECAPTCHA_ENABLE_ALWAYS = "SSOLogin.Recaptcha.EnableAlways";
        public static final String SSO_LOGIN_RECAPTCHA_MAX_ATTEMPTS = "SSOLogin.Recaptcha.MaxAttempts";
    }

    public static final class ReCaptchaConnectorPropertySuffixes {

        public static final String ENABLE = ".enable";

        public static final String ENABLE_ALWAYS = ".enable.always";

        public static final String CONNECTOR_IDENTIFIER_ATTRIBUTE = ".connector.identifier.attribute";

        public static final String MAX_ATTEMPTS = ".on.max.failed.attempts";

        public static final String USER_IDENTIFIER_ATTRIBUTE = ".user.identifier.attribute";

        public static final String RECAPTCHA_VERIFICATION_CLAIM = ".verification.claim";

        public static final String SECURED_DESTINATIONS = ".secured.destinations";

        public static final String SECURED_PAGES = ".secured.pages";
    }

    public static void setEnableSecurityMechanism(String mechanism) {

        enableSecurityMechanism.set(mechanism);
    }

    public static String getEnableSecurityMechanism() {

        return (String) enableSecurityMechanism.get();
    }

    public static void removeEnabledSecurityMechanism() {
        enableSecurityMechanism.remove();
    }
}
